#include <malloc.h>
#include "stdafx.h"

BOOL clear_message_queue(enum queue which) {

	struct message_queue *next_message, *queue;

	EnterCriticalSection(&cs_msg);
	
	switch (which) {
		case INCOMING:
			queue = incoming_msg_queue;
			break;
		case OUTGOING:
			queue = outgoing_msg_queue;
			break;
	}

	while (queue != NULL) {
		next_message = queue->next_message;
		unallocate_message(queue);
		queue = next_message;
	}

	switch (which) {
		case INCOMING:
			incoming_msg_queue = NULL;
			break;
		case OUTGOING:
			outgoing_msg_queue = NULL;
			break;
	}

	LeaveCriticalSection(&cs_msg);
	return TRUE;
}

BOOL add_message(enum queue which, char *message) {

	struct message_queue *new_message, *cur_message, *queue;

	EnterCriticalSection(&cs_msg);
	switch (which) {
		case INCOMING:
			queue = incoming_msg_queue;
			break;
		case OUTGOING:
			queue = outgoing_msg_queue;
			break;
	}
	
	new_message = malloc(sizeof(struct message_queue));
	if (new_message == NULL) {
		// Can't allocate memory. Return
		LeaveCriticalSection(&cs_msg);
		return FALSE;
	}

	new_message->message = malloc(sizeof(char) * 255);
	if (new_message->message == NULL) {
		// Can't allocate memory. Deallocate message memory and return
		free(new_message);
		LeaveCriticalSection(&cs_msg);
		return FALSE;
	}

	// Copy the new message into the queue message ptr
	strncpy(new_message->message, message, 255);
	// Set the next message to NULL
	new_message->next_message = NULL;

	if (queue == NULL) {
		// Our queue is empty, add the first message
		queue = new_message;
		switch (which) {
			case INCOMING:
				incoming_msg_queue = new_message;
				break;
			case OUTGOING:
				outgoing_msg_queue = new_message;
				break;
		}
	} else {
		// Our queue already has some messages in it. Find the last one and add the latest
		cur_message = queue;
		while (cur_message->next_message != NULL) {
			cur_message = cur_message->next_message;
		}
		cur_message->next_message = new_message;
	}

	if ((which == OUTGOING) && (hCallback != 0))
		PostMessage(hCallback, WM_PAINT, 0, 0);

	LeaveCriticalSection(&cs_msg);
	return TRUE;

}

char *get_next_message(enum queue which) {

	struct message_queue *next_message, *queue;
	char *message;

	EnterCriticalSection(&cs_msg);
	switch (which) {
		case INCOMING:
			queue = incoming_msg_queue;
			break;
		case OUTGOING:
			queue = outgoing_msg_queue;
			break;
	}

	message = malloc(sizeof(char) * 255);
	if (message == NULL) {
		LeaveCriticalSection(&cs_msg);
		return NULL;
	}

	if (queue != NULL) {
		next_message = queue->next_message;
		strncpy(message, queue->message, 255);
		unallocate_message(queue);
		queue = next_message;
	} else {
		free(message);
		LeaveCriticalSection(&cs_msg);
		return NULL;
	}

	switch (which) {
		case INCOMING:
			incoming_msg_queue = queue;
			break;
		case OUTGOING:
			outgoing_msg_queue = queue;
			break;
	}

	LeaveCriticalSection(&cs_msg);
	return message;

}

BOOL unallocate_message(struct message_queue *queue) {

	free(queue->message);
	queue->next_message = NULL;
	free(queue);

	return TRUE;

}
